summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-12-01 19:21:09 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2011-12-01 19:27:35 -0600
commit1be5c22e5c1cfb1c2011a36a5a69932b8152de7e (patch)
tree39bd5d68433bc7438fdd6fbc80d7be6130855204 /png.h
parent956c0599e699b0b73aa2e00f3bbd1042731e93b7 (diff)
downloadlibpng-1be5c22e5c1cfb1c2011a36a5a69932b8152de7e.tar.gz
[libpng15] Bump version to libpng-1.5.7rc02
Diffstat (limited to 'png.h')
-rw-r--r--png.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/png.h b/png.h
index ae0f762c2..9d29e00c7 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.7rc01 - December 1, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.7rc01 - December 1, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -196,7 +196,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.7rc01, December 1, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -308,13 +308,13 @@
* Y2K compliance in libpng:
* =========================
*
- * December 1, 2011
+ * December 2, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.7rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -372,9 +372,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.7rc01"
+#define PNG_LIBPNG_VER_STRING "1.5.7rc02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.7rc01 - December 1, 2011\n"
+ " libpng version 1.5.7rc02 - December 2, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -388,7 +388,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -535,7 +535,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_7rc01;
+typedef char* png_libpng_version_1_5_7rc02;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.7rc01 - December 1, 2011
+ * libpng version 1.5.7rc02 - December 2, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.7rc01 - December 1, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.7rc02 - December 2, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -196,7 +196,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.7rc01, December 1, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.7rc02, December 2, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -308,13 +308,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.7rc01 are Y2K compliant. It is my belief that
+ * upward through 1.5.7rc02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*